/*
 * This program source code file is part of KiCad, a free EDA CAD application.
 *
 * Copyright (C) 2013 CERN
 * @author Maciej Suminski <maciej.suminski@cern.ch>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, you may find one here:
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * or you may search the http://www.gnu.org website for the version 2 license,
 * or you may write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

#ifndef __POINT_EDITOR_H
#define __POINT_EDITOR_H

#include <tool/tool_interactive.h>
#include "edit_points.h"

class SELECTION_TOOL;

/**
 * Class POINT_EDITOR
 *
 * Tool that displays edit points allowing to modify items by dragging the points.
 */

class POINT_EDITOR : public TOOL_INTERACTIVE
{
public:
    POINT_EDITOR();

    /// @copydoc TOOL_INTERACTIVE::Reset()
    void Reset( RESET_REASON aReason ) {};

    /// @copydoc TOOL_INTERACTIVE::Init()
    bool Init();

    /**
     * Function OnSelected()
     *
     * Change selection event handler.
     */
    int OnSelected( TOOL_EVENT& aEvent );

private:
    ///> Selection tool used for obtaining selected items
    SELECTION_TOOL* m_selectionTool;

    ///> Currently edited point, NULL if there is none.
    EDIT_POINT* m_dragPoint;

    ///> Updates item's points with edit points.
    void updateItem( EDA_ITEM* aItem, EDIT_POINTS& aPoints ) const;

    ///> Updates edit points with item's points.
    void updatePoints( const EDA_ITEM* aItem, EDIT_POINTS& aPoints ) const;

    ///> Sets up handlers for various events.
    void setTransitions();
};

#endif
